@@ -94,9 +94,10 @@ class BcbioLSFEngineSetLauncher(launcher.LSFEngineSetLauncher):
     batch_file_name = Unicode(unicode("lsf_engine" + str(uuid.uuid4())))
     cores = traitlets.Integer(1, config=True)
     mem = traitlets.Unicode("", config=True)
+    tag = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode("""#!/bin/sh
 #BSUB -q {queue}
-#BSUB -J bcbio-ipengine[1-{n}]
+#BSUB -J bcbio{tag}-ipengine[1-{n}]
 #BSUB -oo bcbio-ipengine.bsub.%%J
 #BSUB -n {cores}
 #BSUB -R "span[hosts=1]"
@@ -113,17 +114,20 @@ class BcbioLSFEngineSetLauncher(launcher.LSFEngineSetLauncher):
             self.context["mem"] = "#BSUB -M %s" % mem
         else:
             self.context["mem"] = ""
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioLSFEngineSetLauncher, self).start(n)
 
 class BcbioLSFControllerLauncher(launcher.LSFControllerLauncher):
     batch_file_name = Unicode(unicode("lsf_controller" + str(uuid.uuid4())))
+    tag = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode("""#!/bin/sh
-#BSUB -J bcbio-ipcontroller
+#BSUB -J bcbio{tag}-ipcontroller
 #BSUB -oo bcbio-ipcontroller.bsub.%%J
 %s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
     """ % (' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
            ' '.join(controller_params)))
     def start(self):
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioLSFControllerLauncher, self).start()
 
 # ## Sun Grid Engine (SGE)
@@ -135,13 +139,14 @@ class BcbioSGEEngineSetLauncher(launcher.SGEEngineSetLauncher):
     pename = traitlets.Unicode("", config=True)
     resources = traitlets.Unicode("", config=True)
     mem = traitlets.Unicode("", config=True)
+    tag = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode("""#$ -V
 #$ -cwd
 #$ -b y
 #$ -j y
 #$ -S /bin/sh
 #$ -q {queue}
-#$ -N bcbio-ipengine
+#$ -N bcbio{tag}-ipengine
 #$ -t 1-{n}
 #$ -pe {pename} {cores}
 {mem}
@@ -157,6 +162,7 @@ echo \($SGE_TASK_ID - 1\) \* 0.5 | bc | xargs sleep
             self.context["mem"] = "#$ -l mem_free=%sM" % int(float(self.mem) * 1024)
         else:
             self.context["mem"] = ""
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         self.context["pename"] = str(self.pename)
         self.context["resources"] = "\n".join(["#$ -l %s" % r.strip()
                                                for r in str(self.resources).split(";")
@@ -165,14 +171,16 @@ echo \($SGE_TASK_ID - 1\) \* 0.5 | bc | xargs sleep
 
 class BcbioSGEControllerLauncher(launcher.SGEControllerLauncher):
     batch_file_name = Unicode(unicode("sge_controller" + str(uuid.uuid4())))
+    tag = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode(u"""#$ -V
 #$ -S /bin/sh
 #$ -cwd
-#$ -N ipcontroller
+#$ -N bcbio{tag}-ipcontroller
 %s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
 """ % (' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
        ' '.join(controller_params)))
     def start(self):
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioSGEControllerLauncher, self).start()
 
 def _find_parallel_environment(queue):
@@ -284,12 +292,13 @@ class BcbioSLURMEngineSetLauncher(SLURMLauncher, launcher.BatchClusterAppMixin):
     machines = traitlets.Integer(1, config=True)
     cores = traitlets.Integer(1, config=True)
     mem = traitlets.Unicode("", config=True)
+    tag = traitlets.Unicode("", config=True)
     account = traitlets.Unicode("", config=True)
     timelimit = traitlets.Unicode("", config=True)
     resources = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode("""#!/bin/sh
 #SBATCH -p {queue}
-#SBATCH -J bcbio-ipengine[1-{n}]
+#SBATCH -J bcbio{tag}-ipengine[1-{n}]
 #SBATCH -o bcbio-ipengine.out.%%j
 #SBATCH -e bcbio-ipengine.err.%%j
 #SBATCH --cpus-per-task={cores}
@@ -309,6 +318,7 @@ class BcbioSLURMEngineSetLauncher(SLURMLauncher, launcher.BatchClusterAppMixin):
             self.context["mem"] = "#SBATCH --mem=%s" % int(float(self.mem) * 1024.0)
         else:
             self.context["mem"] = "#SBATCH --mem=%d" % int(DEFAULT_MEM_PER_CPU * self.cores)
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         self.context["machines"] = self.machines
         self.context["account"] = self.account
         self.context["timelimit"] = self.timelimit
@@ -322,9 +332,10 @@ class BcbioSLURMControllerLauncher(SLURMLauncher, launcher.BatchClusterAppMixin)
     account = traitlets.Unicode("", config=True)
     timelimit = traitlets.Unicode("", config=True)
     mem = traitlets.Unicode("", config=True)
+    tag = traitlets.Unicode("", config=True)
     resources = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode("""#!/bin/sh
-#SBATCH -J bcbio-ipcontroller
+#SBATCH -J bcbio{tag}-ipcontroller
 #SBATCH -o bcbio-ipcontroller.out.%%j
 #SBATCH -e bcbio-ipcontroller.err.%%j
 #SBATCH -A {account}
@@ -338,6 +349,7 @@ class BcbioSLURMControllerLauncher(SLURMLauncher, launcher.BatchClusterAppMixin)
         self.context["account"] = self.account
         self.context["timelimit"] = self.timelimit
         self.context["mem"] = "#SBATCH --mem=%d" % DEFAULT_MEM_PER_CPU
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         self.context["resources"] = "\n".join(["#SBATCH --%s" % r.strip()
                                                for r in str(self.resources).split(";")
                                                if r.strip()])
@@ -393,18 +405,19 @@ class BcbioOLDSLURMControllerLauncher(SLURMLauncher, launcher.BatchClusterAppMix
 
 # ## PBS
 class BcbioPBSEngineSetLauncher(launcher.PBSEngineSetLauncher):
-    """Custom launcher handling heterogeneous clusters on SGE.
+    """Custom launcher handling heterogeneous clusters on PBS.
     """
     batch_file_name = Unicode(unicode("pbs_engines" + str(uuid.uuid4())))
     cores = traitlets.Integer(1, config=True)
     mem = traitlets.Unicode("", config=True)
+    tag = traitlets.Unicode("", config=True)
     pename = traitlets.Unicode("", config=True)
     resources = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode("""#PBS -V
 #PBS -j oe
 #PBS -S /bin/sh
 #PBS -q {queue}
-#PBS -N bcbio-ipengine
+#PBS -N bcbio{tag}-ipengine
 #PBS -t 1-{n}
 {mem}
 %s %s --profile-dir="{profile_dir}" --cluster-id="{cluster_id}"
@@ -418,24 +431,27 @@ class BcbioPBSEngineSetLauncher(launcher.PBSEngineSetLauncher):
             self.context["mem"] = "#PBS -l mem=%smb" % int(float(self.mem) * 1024)
         else:
             self.context["mem"] = ""
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioPBSEngineSetLauncher, self).start(n)
 
 
 class BcbioPBSControllerLauncher(launcher.PBSControllerLauncher):
     batch_file_name = Unicode(unicode("pbs_controller" + str(uuid.uuid4())))
+    tag = traitlets.Unicode("", config=True)
     default_template = traitlets.Unicode(u"""#PBS -V
 #PBS -S /bin/sh
-#PBS -N ipcontroller
+#PBS -N bcbio{tag}-ipcontroller
 %s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
 """ % (' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
        ' '.join(controller_params)))
 
     def start(self):
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioPBSControllerLauncher, self).start()
 
 # ## Torque
 class TORQUELauncher(launcher.BatchSystemLauncher):
-    """A BatchSystemLauncher subclass for PBS."""
+    """A BatchSystemLauncher subclass for Torque"""
 
     submit_command = List(['qsub'], config=True,
                           help="The PBS submit command ['qsub']")
@@ -452,15 +468,16 @@ class TORQUELauncher(launcher.BatchSystemLauncher):
 
 
 class BcbioTORQUEEngineSetLauncher(TORQUELauncher, launcher.BatchClusterAppMixin):
-    """Launch Engines using PBS"""
+    """Launch Engines using Torque"""
     cores = traitlets.Integer(1, config=True)
     mem = traitlets.Unicode("", config=True)
+    tag = traitlets.Unicode("", config=True)
     batch_file_name = Unicode(unicode("torque_engines" + str(uuid.uuid4())),
                               config=True, help="batch file name for the engine(s) job.")
     default_template = Unicode(u"""#!/bin/sh
 #PBS -V
 #PBS -j oe
-#PBS -N ipengine
+#PBS -N bcbio{tag}-ipengine
 #PBS -t 1-{n}
 #PBS -l nodes=1:ppn={cores}
 {mem}
@@ -477,17 +494,18 @@ cd $PBS_O_WORKDIR
             self.context["mem"] = "#PBS -l mem=%smb" % int(float(self.mem) * 1024)
         else:
             self.context["mem"] = ""
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioTORQUEEngineSetLauncher, self).start(n)
 
 
 class BcbioTORQUEControllerLauncher(TORQUELauncher, launcher.BatchClusterAppMixin):
-    """Launch a controller using PBS."""
+    """Launch a controller using Torque."""
     batch_file_name = Unicode(unicode("torque_controller" + str(uuid.uuid4())),
                               config=True, help="batch file name for the engine(s) job.")
-
+    tag = traitlets.Unicode("", config=True)
     default_template = Unicode("""#!/bin/sh
 #PBS -V
-#PBS -N ipcontroller
+#PBS -N bcbio{tag}-ipcontroller
 #PBS -j oe
 #PBS -l walltime=239:00:00
 cd $PBS_O_WORKDIR
@@ -497,6 +515,7 @@ cd $PBS_O_WORKDIR
 
     def start(self):
         """Start the controller by profile or profile_dir."""
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioTORQUEControllerLauncher, self).start(1)
 
 
@@ -511,9 +530,10 @@ class BcbioPBSPROEngineSetLauncher(PBSPROLauncher, launcher.BatchClusterAppMixin
     """Launch Engines using PBSPro"""
     batch_file_name = Unicode(u'pbspro_engines', config=True,
                               help="batch file name for the engine(s) job.")
+    tag = traitlets.Unicode("", config=True)
     default_template = Unicode(u"""#!/bin/sh
 #PBS -V
-#PBS -N ipengine
+#PBS -N bcbio{tag}-ipengine
 cd $PBS_O_WORKDIR
 %s %s --profile-dir="{profile_dir}" --cluster-id="{cluster_id}"
     """ % (' '.join(map(pipes.quote, engine_cmd_argv)),
@@ -521,6 +541,7 @@ cd $PBS_O_WORKDIR
 
     def start(self, n):
         """Start n engines by profile or profile_dir."""
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioPBSPROEngineSetLauncher, self).start(n)
 
 
@@ -529,9 +550,10 @@ class BcbioPBSPROControllerLauncher(PBSPROLauncher, launcher.BatchClusterAppMixi
 
     batch_file_name = Unicode(u'pbspro_controller', config=True,
                               help="batch file name for the controller job.")
+    tag = traitlets.Unicode("", config=True)
     default_template = Unicode("""#!/bin/sh
 #PBS -V
-#PBS -N ipcontroller
+#PBS -N bcbio{tag}-ipcontroller
 cd $PBS_O_WORKDIR
 %s --ip=* --log-to-file --profile-dir="{profile_dir}" --cluster-id="{cluster_id}" %s
 """ % (' '.join(map(pipes.quote, launcher.ipcontroller_cmd_argv)),
@@ -539,6 +561,7 @@ cd $PBS_O_WORKDIR
 
     def start(self):
         """Start the controller by profile or profile_dir."""
+        self.context["tag"] = "-%s" % self.tag if self.tag else ""
         return super(BcbioPBSPROControllerLauncher, self).start(1)
 
 
@@ -608,6 +631,8 @@ def _start(scheduler, profile, queue, num_jobs, cores_per_job, cluster_id,
          "--%s.resources='%s'" % (engine_class, resources),
          "--%s.mem='%s'" % (engine_class, extra_params.get("mem", "")),
          "--%s.mem='%s'" % (controller_class, extra_params.get("mem", "")),
+         "--%s.tag='%s'" % (engine_class, extra_params.get("tag", "")),
+         "--%s.tag='%s'" % (controller_class, extra_params.get("tag", "")),
          "--IPClusterStart.controller_launcher_class=%s.%s" % (ns, controller_class),
          "--IPClusterStart.engine_launcher_class=%s.%s" % (ns, engine_class),
          "--%sLauncher.queue='%s'" % (scheduler, queue),
